@@ -791,12 +791,6 @@ main_x_init( int *argc, char ***argv )
 			"ipgtkrc", NULL, NULL, NULL );
 	gtk_init( argc, argv );
 
-#ifdef HAVE_LIBGOFFICE
-        libgoffice_init();
-	go_plugins_init( NULL, NULL, NULL, NULL, TRUE, 
-		GO_TYPE_PLUGIN_LOADER_MODULE );
-#endif /*HAVE_LIBGOFFICE*/
-
 	/* Set the default icon. 
 	 */
 	im_strncpy( buf, 
@@ -1093,11 +1087,6 @@ main( int argc, char *argv[] )
 	if( im_init_world( main_argv0 ) )
 		error_exit( "unable to start VIPS" );
 
-	/* We don't want the vips operation cache: it doesn't know about
-	 * invalidate and breaks various things.
-	 */
-	vips_cache_set_max( 0 );
-
 	/* Init i18n ... get catalogues from $VIPSHOME/share/locale so we're
 	 * relocatable.
 	 */
@@ -1301,6 +1290,12 @@ main( int argc, char *argv[] )
 	if( !main_option_batch )
 		main_x_init( &argc, &argv );
 
+#ifdef HAVE_LIBGOFFICE
+        libgoffice_init();
+	go_plugins_init( NULL, NULL, NULL, NULL, TRUE, 
+		GO_TYPE_PLUGIN_LOADER_MODULE );
+#endif /*HAVE_LIBGOFFICE*/
+
 	/* Load start-up stuff. Builtins, plugins, externals etc. We need to
 	 * do this before we load any user code so we can prevent redefinition
 	 * of builtins.
