@@ -66,6 +66,10 @@ struct _Plot {
 	ImageValue value;
 	PlotFormat format;
 	PlotStyle style;
+	char *caption; 
+	char *xcaption; 
+	char *ycaption; 
+	GSList *series_captions;
 	double xmin;
 	double xmax;
 	double ymin;
@@ -104,5 +108,8 @@ char *plot_s2c( PlotStyle style );
 
 #ifdef HAVE_LIBGOFFICE
 GogPlot *plot_new_gplot( Plot *plot );
+void plot_style_main( Plot *plot, GogChart *gchart );
+void plot_style_thumbnail( Plot *plot, GogChart *gchart );
+Imageinfo *plot_to_image( Plot *plot, Reduce *rc, double dpi );
 #endif /*HAVE_LIBGOFFICE*/
 
